@@ -7,11 +7,9 @@ use WebService::Nestoria::Search::Result;
 
 =head1 NAME
 
-WebService::Nestoria::Search::Response - Container object for the result set 
-of a query to the Nestoria Search API.
+WebService::Nestoria::Search::Response - Container object for the result set of a query to the Nestoria Search API.
 
-This package is used by WebService::Nestoria::Search and a C<Result> object 
-should never need to be explicitly created by the user.
+This package is used by WebService::Nestoria::Search and a WebService::Nestoria::Search::Result object should never need to be explicitly created by the user.
 
 =cut
 
@@ -20,7 +18,7 @@ sub new {
     my $self;
 
     $self->{data} = shift;
-    $self->{json} = shift;
+    $self->{raw} = shift;
     $self->{next_iterator} = 0;
 
     my $listings = $self->{data}{response}{listings} || [];
@@ -41,10 +39,32 @@ sub new {
 
 =head1 Functions
 
+=head2 get_raw
+
+Returns the raw data returned by the Nestoria API. By default this will be JSON (JavaScript Object Notation.) C<get_json> and C<get_xml> are aliases to C<get_raw>.
+
+Functions other than C<get_raw> only work if encoding was set to 'json'. If encoding is set to anything else ('xml' for example) then C<results> will return an empty array, C<get_hashref> a reference to an empty hash, etc.
+
+=cut
+
+sub get_raw {
+    my $self = shift;
+    return $self->{json};
+}
+
+sub get_json {
+    my $self = shift;
+    return $self->get_raw;
+}
+
+sub get_xml {
+    my $self = shift;
+    return $self->get_raw;
+}
+
 =head2 status_code
 
-Returns the status code of the response. 200 on success, various other numbers
-on errors.
+Returns the status code of the response. 200 on success, various other numbers on errors.
 
 =cut
 
@@ -53,22 +73,11 @@ sub status_code {
     return $self->{data}{response}{status_code};
 }
 
-=head2 get_json
 
-Returns the unchanged JSON (JavaScript Object Notation) returned by the
-Nestoria API
-
-=cut
-
-sub get_json {
-    my $self = shift;
-    return $self->{json};
-}
 
 =head2 get_hashref
 
-Returns a reference to a hash that contains exactly what the response from
-the Nestoria API gave, converted from JSON to a hashref with JSON::jsonToObj()
+Returns a reference to a hash that contains exactly what the response from the Nestoria API gave, converted from JSON into a hashref with JSON::jsonToObj()
 
 =cut
 
@@ -79,8 +88,7 @@ sub get_hashref {
 
 =head2 count
 
-Returns the number of listings found. These can be accessed as C<Result>
-objects by calling the methods mentioned below.
+Returns the number of listings found.
 
 =cut
 
@@ -91,8 +99,7 @@ sub count {
 
 =head2 results
 
-Returns an array of listings (C<Result> objects) containing all
-the information about the listings returned by the Nestoria API.
+Returns an array of WebService::Nestoria::Search::Result objects, each containing data about a single listing returned by the Nestoria API.
 
 =cut
 
@@ -103,8 +110,7 @@ sub results {
 
 =head2 next_result
 
-Returns the next C<Result> object to be fetched. When out of listings
-returns C<undef>, making it suitable for use in while loops.
+Returns the next WebService::Nestoria::Search::Result object to be fetched. When out of listings returns C<undef>, making it suitable for use in while loops.
 
     while ( $listing = $result->next_result ) {
         # do something;
